@@ -73,8 +73,9 @@ int opt_kill=0;
 int opt_repeater=0, opt_double=0;
 int opt_kernel;
 int opt_explicittype; /* kmouse defaults to autodetection */
+char *opt_special=NULL; /* special commands, like reboot or such */
+char *consolename = "/dev/tty0";
 static int opt_resize=0; /* not really an option */
-
 char *prgname;
 struct winsize win;
 int maxx, maxy;
@@ -94,8 +95,8 @@ static inline int open_console(const int mode)
 {
 int fd;
 
-  if ((fd=open("/dev/console", mode)) < 0)
-    oops("/dev/console");
+  if ((fd=open(consolename, mode)) < 0)
+    oops(consolename);
   return fd;
 }
 
@@ -411,16 +412,13 @@ static int newB=0, oldB=0, oldT=0; /* old buttons and Type to chain events */
 
   if (kd_mode!=KD_TEXT)
     {
-    unsigned char buffer[5];
+    signed char buffer[5];
 
     /* sluggish... */
     buffer[0]=(event->buttons ^ 0x07) | 0x80;
-    buffer[1]=(event->dx>>1) &0xFF;
-    buffer[2]=-(event->dy>>1) &0xFF;
-    buffer[3]=buffer[1] + (event->dx & 1);
-    buffer[4]=buffer[2] - (event->dy & 1);
+    buffer[3] =  event->dx - (buffer[1] = event->dx/2); /* Markus */
+    buffer[4] = -event->dy - (buffer[2] = -event->dy/2);
     write(fifofd,buffer,5);
-    
     return 0; /* no events nor information for clients */
     }
 
@@ -527,6 +525,9 @@ static int newB=0, oldB=0, oldT=0; /* old buttons and Type to chain events */
   /* update the global state */
   statusX=event->x; statusY=event->y;
 
+  if (opt_special && event->type & GPM_DOWN) 
+    return processSpecial(event);
+
   return 1;
 }
 
