@@ -1,7 +1,7 @@
 /*
  * gpm-Linux configuration file (server only)
  *
- * Copyright 1994,1995   rubini@ipvvis.unipv.it
+ * Copyright 1994-1996   rubini@ipvvis.unipv.it
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -19,8 +19,8 @@
  ********/
 
 #define GPM_NAME    "gpm-Linux"
-#define GPM_RELEASE "1.09"
-#define GPM_DATE    "May 1996"
+#define GPM_RELEASE "1.10"
+#define GPM_DATE    "July 1996"
 
 /* You can define DEBUG, or undefine it. */
 /* Well, better putting it in the Makefile... */
