@@ -120,7 +120,9 @@ extern int opt_test, opt_ptrdrag;
 extern int opt_kill;
 extern int opt_repeater, opt_double;
 extern int opt_kernel, opt_explicittype;
+extern char *opt_special;
 extern int fifofd;
+extern char *consolename; /* the selected one */
 
 extern Gpm_Type mice[];
 extern struct winsize win;
@@ -140,6 +142,8 @@ int cmdline(int argc, char **argv);
 int giveInfo(int request, int fd);
        /* mice.c */
 extern int M_listTypes(void);
+       /* special.c */
+int processSpecial(Gpm_Event *event);
 
 /*....................................... Dirty hacks */
 
